# Welcome!

Contributions are very welcome on {{ PROJECT }}. When contributing please keep this in mind:

- Open an issue to discuss new bigger features.
- Write code consistent with the project style and make sure the tests are passing.
- Stay in touch with us if we have follow up questions or requests for further changes.

# Development

## Local Environment


## Tests


## Static checking and Linting


## Manual testing


## Building the package

### On Fedora
```shell
sudo make fedora-dev-setup
make rpm
```

## Configuration


# Opening a PR

- Commit messages should describe the changes, not the filenames. Win our admiration by following
  the [excellent advice from Chris Beams](https://chris.beams.io/posts/git-commit/) when composing
  commit messages.
- Choose a meaningful title for your pull request.
- The pull request description should focus on what changed and why.
- Check that the tests pass (and add test coverage for your changes if appropriate).
